@@ -36,6 +36,7 @@ as follows:
     get_longitude
     get_listing_type
     get_property_type
+    get_datasource_name
     get_lister_name
     get_lister_url
     get_price
@@ -47,6 +48,7 @@ as follows:
     get_thumb_url
     get_thumb_height
     get_thumb_width
+    get_keywords
 
 =cut
 
@@ -70,6 +72,11 @@ sub get_property_type {
     return $self->{data}{listing}{property_type};
 }
 
+sub get_datasource_name {
+    my $self = shift;
+    return $self->{data}{listing}{datasource_name};
+}
+
 sub get_lister_name {
     my $self = shift;
     return $self->{data}{listing}{lister_name};
@@ -125,6 +132,11 @@ sub get_thumb_width {
     return $self->{data}{listing}{thumb_width};
 }
 
+sub get_keywords {
+    my $self = shift;
+    return $self->{data}{listing}{keywords};
+}
+
 =head2 get_hashref
 
 Returns a hashref containing the details of the listing with keys exactly as
